@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-import sys
-sys.path.append('../')
+import sys,os
+
 from ctypes import *
 import ctypes
 import numpy as np
@@ -27,7 +27,17 @@ def cal_PCC(refData, testData,calSize,mydll):
     mydll.Pearson_Correlation(refstruct,teststruct,c_long(calSize),byref(pcc))
     return pcc.value
 
+def get_max_cc_by_dll(refData, testData,mydll,step):
+    """
+    (double *x, double *y,long xLenth,long yLenth,long step,double *maxcc,long *startPoint)
+    """
 
+    refstruct = np.ascontiguousarray(refData, dtype=c_double).ctypes.data_as(ctypes.POINTER(c_double))
+    teststruct = np.ascontiguousarray(testData, dtype=c_double).ctypes.data_as(ctypes.POINTER(c_double))
+    mydll.get_max_pcc.argtypes = [POINTER(c_double),POINTER(c_double),c_long,c_long,c_long,POINTER(c_double),POINTER(c_long)]
+    max_cc,start_point = c_double(0.0),c_long(0)
+    mydll.get_max_pcc(refstruct,teststruct,c_long(len(refData)),c_long(len(testData)),c_long(step),byref(max_cc),byref(start_point))
+    return max_cc.value,start_point.value
 
 
 if __name__ == '__main__':
