@@ -1,9 +1,7 @@
 # -*- coding: UTF-8 -*-
-import  sys
-import os
-from os import path
-sys.path.append('./')
-sys.path.append('../')
+import sys,os
+from os import  path
+sys.path.append((os.path.dirname(path.dirname(__file__))))
 from ctypes import *
 import sys
 import  time
