@@ -4,14 +4,14 @@ import sys,os
 from os import  path
 sys.path.append(os.path.dirname(path.dirname(__file__)))
 sys.path.append(path.dirname(__file__))
-from commFunction import getip,log_time,global_result,sftp_connect,sftp_put,sftp_disconnect,get_file_path
+from commFunction import getip,log_time,global_result,sftp_connect,sftp_put,sftp_disconnect,get_file_path,get_data_array,get_rms,make_out_file
 import shutil
 from  socketClient import SocketClient
 import datetime
 
 
 
-def polqa_client_test(src,test,samplerate):
+def polqa_client_test(src,test,samplerate,mode=0):
     curip = getip()
     curtime = log_time()
     curpath = str(curip) + '_'+str(curtime)
@@ -28,7 +28,17 @@ def polqa_client_test(src,test,samplerate):
     #ssh
     shutil.copy(src,curpath)
     shutil.copy(test, curpath)
+    if mode == 1:
+        curFileName = curpath + '//' + curdata['testFile']
+        curaudiodata,curfs,curch = get_data_array(curFileName)
 
+
+        currms = get_rms(curaudiodata)
+        adjustlevel = -26 - currms
+
+        factor = 10 ** (adjustlevel / 20)
+        urframe = curaudiodata * factor
+        make_out_file(curFileName,urframe,curfs,curch)
     dstpath = '/home/netease/polqa'
 
 
@@ -53,6 +63,8 @@ if __name__ == '__main__':
     import platform
     print(platform.uname())
     print(sys.platform)
+    polqa_client_test(src='src.wav',test='2.wav',samplerate=48000,mode=1)
+
     exit(0)
     # client, sftp = sftp_connect(username, password, serverIP, port=port)
     # sftp_get(sftp, '/home/netease/polqa_result/' + '192.168.1.3_2021-08-18-17-52-35' + '.ress', 'result')
