@@ -59,6 +59,7 @@ def match_sig(refFile=None,testFile=None,outFile=None,audioType=0):
     delay, err = c_double(0.0), c_double(0.0)
     mydll.matchsig_2(byref(refstruct), byref(teststruct), byref(outStruct),c_double(refsamplerate),c_double(audioType),byref(delay), byref(err))
     if err.value > 0.0:
+        print(err.value)
         return None
     else:
         if outFile is not None:
@@ -69,8 +70,8 @@ def match_sig(refFile=None,testFile=None,outFile=None,audioType=0):
 
 
 if __name__ == '__main__':
-    ref = r'C:\Users\vcloud_avl\Documents\我的POPO\src.wav'
-    test = r'C:\Users\vcloud_avl\Documents\我的POPO\test.wav'
-    print(match_sig(refFile=ref, testFile=test, outFile='outfile.wav'))
+    test = 'test.wav'
+    ref = 'left_channel_test.wav'
+    print(match_sig(refFile=ref, testFile=test, outFile='outfile.wav',audioType=1))
 
     pass
\ No newline at end of file
